.. include:: ../README.rst

----

.. toctree::

    installation
    examples/index
    arrays
    frequency-domain
    time-domain
    plotting
    utilities
    references
    contributing
    version-history

.. only:: html

    * :ref:`genindex`
